#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.edge_fillet import EdgeFillet


class VarRadEdgeFillet(EdgeFillet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             PartInterfaces.Fillet
                |                                 PartInterfaces.EdgeFillet
                |                                     VarRadEdgeFillet
                | 
                | Represents the edge fillet shape with a variable radius.
                | The resulting shape is made up of edges fillets controlled by couples of
                | radius/vertex.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.var_rad_edge_fillet = com_object

    @property
    def bitangency_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BitangencyType() As CatFilletBitangencyType
                | 
                |     Returns or set the fillet bitangency type.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type used to perform the fillet : catSphereBitangencyType or catCircleBitangencyType

        :return: enum cat_fillet_bitangency_type
        :rtype: int
        """

        return self.var_rad_edge_fillet.BitangencyType

    @bitangency_type.setter
    def bitangency_type(self, value: int):
        """
        :param int value: enum cat_fillet_bitangency_type
        """

        self.var_rad_edge_fillet.BitangencyType = value

    @property
    def edges_to_fillet(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EdgesToFillet() As References (Read Only)
                | 
                |     Returns the collection of edges to be filleted.
                | 
                |     Example:
                |         The following example returns in edges the edges to fillet of variable
                |         radius edge filletfirstVarEdgeFillet:
                | 
                |          Set edges = firstVarEdgeFillet.EdgesToFillet

        :rtype: References
        """

        return References(self.var_rad_edge_fillet.EdgesToFillet)

    @property
    def fillet_spine(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FilletSpine() As Reference
                | 
                |     Returns or set the spine for circle bitangency fillet.
                | 
                |     Parameters:
                | 
                |         iSpin
                |             The spine to be used for a circle bitangency
                |             fillet

        :rtype: Reference
        """

        return Reference(self.var_rad_edge_fillet.FilletSpine)

    @fillet_spine.setter
    def fillet_spine(self, value: Reference):
        """
        :param Reference value:
        """

        self.var_rad_edge_fillet.FilletSpine = value.com_object

    @property
    def fillet_variation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FilletVariation() As CatFilletVariation
                | 
                |     Returns or sets the edge fillet radius variation mode.
                | 
                |     Example:
                |         The following example returns in mode the radius variation mode of the
                |         variable radius edge filletfirstVarEdgeFillet, and then sets it to
                |         CATLinearFilletVariation so that the radius variation is linear between two
                |         control vertices:
                | 
                |          mode = firstVarEdgeFillet.FilletVariation
                |          firstVarEdgeFillet.FilletVariation = CATLinearFilletVariation

        :return: enum cat_fillet_variation
        :rtype: int
        """

        return self.var_rad_edge_fillet.FilletVariation

    @fillet_variation.setter
    def fillet_variation(self, value: int):
        """
        :param int value: enum cat_fillet_variation
        """

        self.var_rad_edge_fillet.FilletVariation = value

    @property
    def imposed_vertices(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ImposedVertices() As References (Read Only)
                | 
                |     Returns the collection of vertices where a radius has been
                |     imposed.
                | 
                |     Example:
                |         The following example returns in vertices the collection of imposed
                |         vertices of the variable radius edge
                |         filletfirstVarEdgeFillet:
                | 
                |          Set vertices = firstVarEdgeFillet.ImposedVertices

        :rtype: References
        """

        return References(self.var_rad_edge_fillet.ImposedVertices)

    def add_edge_to_fillet(self, i_edge: Reference, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddEdgeToFillet(Reference iEdge,
                | double iRadius)
                | 
                |     Adds a new edge to the variable radius edge fillet.
                | 
                |     Parameters:
                | 
                |         iEdge
                |             The edge to be filleted
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                |     iRadius
                |         The radius to impose along the edge. This radius is imposed at both end
                |         points of the edge. 
                | 
                | Example:
                |     The following example adds the new edge edge to be filleted to the variable
                |     radius edge fillet firstVarEdgeFillet:
                | 
                |      call firstVarEdgeFillet.AddEdgeToFillet(edge, 5.)

        :param Reference i_edge:
        :param float i_radius:
        :rtype: None
        """
        return self.var_rad_edge_fillet.AddEdgeToFillet(i_edge.com_object, i_radius)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_edge_to_fillet'
        # # vba_code = """
        # # Public Function add_edge_to_fillet(var_rad_edge_fillet)
        # #     Dim iEdge (2)
        # #     var_rad_edge_fillet.AddEdgeToFillet iEdge
        # #     add_edge_to_fillet = iEdge
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_imposed_vertex(self, i_vertex: Reference, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddImposedVertex(Reference iVertex,
                | double iRadius)
                | 
                |     Adds a new control couple. A control couple is made up of a vertex and a
                |     radius.
                | 
                |     Parameters:
                | 
                |         iVertex
                |             The vertex where to impose the radius 
                |         iRadius
                |             The radius to impose at the given vertex 
                | 
                |     Example:
                |         The following example adds a new control couple (vertex, radius) to the
                |         variable radius edge fillet firstVarEdgeFillet set with the vertex vertex and a
                |         radius of 50.
                | 
                |          call firstVarEdgeFillet.AddImposedVertex(vertex, 50.)

        :param Reference i_vertex:
        :param float i_radius:
        :rtype: None
        """
        return self.var_rad_edge_fillet.AddImposedVertex(i_vertex.com_object, i_radius)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_imposed_vertex'
        # # vba_code = """
        # # Public Function add_imposed_vertex(var_rad_edge_fillet)
        # #     Dim iVertex (2)
        # #     var_rad_edge_fillet.AddImposedVertex iVertex
        # #     add_imposed_vertex = iVertex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def imposed_vertex_radius(self, i_imposed_vertex: Reference) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ImposedVertexRadius(Reference iImposedVertex) As
                | Length
                | 
                |     Returns the fillet radius on an imposed vertex.
                | 
                |     Parameters:
                | 
                |         iImposedVertex
                |             The vertex where to retrieve the fillet radius 
                | 
                |     Returns:
                |         The fillet radius 
                |     Example:
                |         The following example returns in radius the fillet radius of the
                |         variable radius edge fillet firstVarEdgeFillet at the vertex
                |         vertex:
                | 
                |          Set radius = firstVarEdgeFillet.ImposedVertexRadius(vertex)

        :param Reference i_imposed_vertex:
        :rtype: Length
        """
        return Length(self.var_rad_edge_fillet.ImposedVertexRadius(i_imposed_vertex.com_object))

    def withdraw_edge_to_fillet(self, i_edge: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawEdgeToFillet(Reference iEdge)
                | 
                |     Withdraws an edge from the variable radius edge fillet.
                | 
                |     Parameters:
                | 
                |         iEdge
                |             The edge to be withdrawn
                |             The following 
                | 
                |         Boundary object is supported: TriDimFeatEdge. 
                | 
                | Example:
                |     The following example withdraws the edge edge from those to be filleted of
                |     the variable radius edge fillet firstVarEdgeFillet:
                | 
                |      call firstVarEdgeFillet.WithdrawEdgeToFillet(edge)

        :param Reference i_edge:
        :rtype: None
        """
        return self.var_rad_edge_fillet.WithdrawEdgeToFillet(i_edge.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_edge_to_fillet'
        # # vba_code = """
        # # Public Function withdraw_edge_to_fillet(var_rad_edge_fillet)
        # #     Dim iEdge (2)
        # #     var_rad_edge_fillet.WithdrawEdgeToFillet iEdge
        # #     withdraw_edge_to_fillet = iEdge
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_imposed_vertex(self, i_vertex: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawImposedVertex(Reference iVertex)
                | 
                |     Withdraws a control couple.
                | 
                |     Parameters:
                | 
                |         iVertex
                |             The vertex where the radius is imposed 
                | 
                |     Example:
                |         The following example withdraws the imposed radius on the vertex vertex
                |         for the variable radius edge fillet
                |         firstVarEdgeFillet:
                | 
                |          call firstVarEdgeFillet.WithdrawImposedVertex(vertex)

        :param Reference i_vertex:
        :rtype: None
        """
        return self.var_rad_edge_fillet.WithdrawImposedVertex(i_vertex.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_imposed_vertex'
        # # vba_code = """
        # # Public Function withdraw_imposed_vertex(var_rad_edge_fillet)
        # #     Dim iVertex (2)
        # #     var_rad_edge_fillet.WithdrawImposedVertex iVertex
        # #     withdraw_imposed_vertex = iVertex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'VarRadEdgeFillet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class HtsJointSpeedSettingsAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         HtsJointSpeedSettingsAtt
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIAHtsJointSpeedSettingAtt are
                | ...
                | 
                | Do not use the DNBIAHtsJointSpeedSettingAtt interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hts_joint_speed_settings_att = com_object

    @property
    def all_joints_speed(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AllJointsSpeed() As CATBSTR
                | 
                |     Returns or sets the JointSpeed parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.hts_joint_speed_settings_att.AllJointsSpeed

    @all_joints_speed.setter
    def all_joints_speed(self, value: str):
        """
        :param str value:
        """

        self.hts_joint_speed_settings_att.AllJointsSpeed = value

    @property
    def rating(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Rating() As CATBSTR
                | 
                |     Returns or sets the Rating parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.hts_joint_speed_settings_att.Rating

    @rating.setter
    def rating(self, value: str):
        """
        :param str value:
        """

        self.hts_joint_speed_settings_att.Rating = value

    def get_all_joints_speed_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAllJointsSpeedInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the JointSpeed parameter.
                |     Role:Retrieves the state of the JointSpeed parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_joint_speed_settings_att.GetAllJointsSpeedInfo(io_admin_level, io_locked)

    def get_rating_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRatingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Rating
                |     parameter.
                |     Role:Retrieves the state of the Rating parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_joint_speed_settings_att.GetRatingInfo(io_admin_level, io_locked)

    def set_all_joints_speed_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAllJointsSpeedLock(boolean iLocked)
                | 
                |     Locks or unlocks the JointSpeed parameter.
                |     Role:Locks or unlocks the JointSpeed parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_joint_speed_settings_att.SetAllJointsSpeedLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_all_joints_speed_lock'
        # # vba_code = """
        # # Public Function set_all_joints_speed_lock(hts_joint_speed_settings_att)
        # #     Dim iLocked (2)
        # #     hts_joint_speed_settings_att.SetAllJointsSpeedLock iLocked
        # #     set_all_joints_speed_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rating_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRatingLock(boolean iLocked)
                | 
                |     Locks or unlocks the Rating parameter.
                |     Role:Locks or unlocks the Rating parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_joint_speed_settings_att.SetRatingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rating_lock'
        # # vba_code = """
        # # Public Function set_rating_lock(hts_joint_speed_settings_att)
        # #     Dim iLocked (2)
        # #     hts_joint_speed_settings_att.SetRatingLock iLocked
        # #     set_rating_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HtsJointSpeedSettingsAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class TreeTabSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         TreeTabSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tree_tab_setting_att = com_object

    @property
    def applicative_data_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplicativeDataFilter() As long
                | 
                |     Returns of sets the value to signify Whether "Applicative Data" created by
                |     an application is visible in the PPR tree
                |     Role: Returns or sets the value of "Applicative Data" option to signify
                |     whether the applicative containers are visualized in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.ApplicativeDataFilter

    @applicative_data_filter.setter
    def applicative_data_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.ApplicativeDataFilter = value

    @property
    def assigned_viewer(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AssignedViewer() As long
                | 
                |     Returns or sets the value to signify whether the 3D Assigned Viewer is
                |     default viewer or not
                |     Role: Returns or sets the value to signify whether 3D Assigned Viewer is
                |     default viewer or not

        :rtype: int
        """

        return self.tree_tab_setting_att.AssignedViewer

    @assigned_viewer.setter
    def assigned_viewer(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.AssignedViewer = value

    @property
    def attributes_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttributesFilter() As long
                | 
                |     Returns or sets the value for "Attributes" option
                |     Role: Returns or sets the value of "Attributes" option to signify whether
                |     the 'User Attributes' of an Activity is visualized in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.AttributesFilter

    @attributes_filter.setter
    def attributes_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.AttributesFilter = value

    @property
    def collapse_expand_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CollapseExpandFilter() As long
                | 
                |     Returns or sets the value to signify Whether the double clicking on an
                |     activity expands/collapses a given activity in the PPR
                |     tree
                |     Role: Returns or sets the value to signify Whether the double clicking on
                |     an activity expands/collapses a given activity in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.CollapseExpandFilter

    @collapse_expand_filter.setter
    def collapse_expand_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.CollapseExpandFilter = value

    @property
    def display_name_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayNameMode() As long
                | 
                |     Returns or sets the value to signify whether the E5 Configured Name is to
                |     be displayed
                |     Role: Returns or sets the value to signify whether the E5 Configured Name
                |     is to be displayed

        :rtype: int
        """

        return self.tree_tab_setting_att.DisplayNameMode

    @display_name_mode.setter
    def display_name_mode(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.DisplayNameMode = value

    @property
    def display_order(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayOrder() As long
                | 
                |     Returns or sets the value for 'Display Order'
                |     Role: Returns or sets the value of 'Display Order' to signify which order
                |     the product/resource list are in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.DisplayOrder

    @display_order.setter
    def display_order(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.DisplayOrder = value

    @property
    def display_process_order(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayProcessOrder() As long
                | 
                |     Returns or sets the value for 'Display Order for
                |     Processes'
                |     Role: Returns or sets the value of 'Display Order for Processes' to signify
                |     which order the processes under ProcessList and ResourcesList are listed in the
                |     PPR tree. Legal values:
                |     1 : manufacturing hub order
                |     0 : loaded order

        :rtype: int
        """

        return self.tree_tab_setting_att.DisplayProcessOrder

    @display_process_order.setter
    def display_process_order(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.DisplayProcessOrder = value

    @property
    def items_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ItemsFilter() As long
                | 
                |     Returns or sets the value for 'Items Folder'
                |     Role: Returns or sets the value of 'Items Folder' to signify whether the
                |     'Assigned Items' are visualized in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.ItemsFilter

    @items_filter.setter
    def items_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.ItemsFilter = value

    @property
    def items_per_relation_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ItemsPerRelationFilter() As long
                | 
                |     Returns or sets the value for 'Items Folder (Per Relation
                |     Type)'
                |     Role: Returns or sets the value of 'Items Folder(Per Relation Type)' to
                |     signify whether the 'Assigned Items'with proper relations ( like First
                |     Processes Product) are visualized in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.ItemsPerRelationFilter

    @items_per_relation_filter.setter
    def items_per_relation_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.ItemsPerRelationFilter = value

    @property
    def logical_act_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LogicalActFilter() As long
                | 
                |     Returns or sets the value to signify Whether the logical activites are
                |     visible in the PPR tree
                |     Role: Returns or sets the value of "Logical Activities" option to signify
                |     whether the logical activites are visible in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.LogicalActFilter

    @logical_act_filter.setter
    def logical_act_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.LogicalActFilter = value

    @property
    def output_product_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputProductFilter() As long
                | 
                |     Returns of sets the value to signify Whether "Output Products" assigned to
                |     a given activity is visible in the PPR tree
                |     Role: Returns or sets the value of "Output Products Folder" option to
                |     signify whether the output products associated with an activity are visualized
                |     in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.OutputProductFilter

    @output_product_filter.setter
    def output_product_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.OutputProductFilter = value

    @property
    def paste_same_instance(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PasteSameInstance() As long
                | 
                |     Returns or sets the value for 'Paste Same Instance'
                |     Role: Returns or sets the value of 'Paste Same Instance' to signify whether
                |     a same product instance in the target process document should be reused or not.
                |     Legal values:
                |     1 : Always paste an instance and do not reuse existing one
                |     0 : Reuse existing instance wherever possible

        :rtype: int
        """

        return self.tree_tab_setting_att.PasteSameInstance

    @paste_same_instance.setter
    def paste_same_instance(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.PasteSameInstance = value

    @property
    def render_style(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RenderStyle() As long
                | 
                |     Returns or sets the value to signify whether the 3D Render Style is
                |     Parallel or Perspective
                |     Role: Returns or sets the value to signify whether the 3D Render Style is
                |     Parallel or Perspective

        :rtype: int
        """

        return self.tree_tab_setting_att.RenderStyle

    @render_style.setter
    def render_style(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.RenderStyle = value

    @property
    def resource_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ResourceFilter() As long
                | 
                |     Returns or sets the value for 'Resources Folder'
                |     Role: Returns or sets the value of 'Resources Folder' to signify whether
                |     the 'Assigned Resources' are visualized in the PPR tree

        :rtype: int
        """

        return self.tree_tab_setting_att.ResourceFilter

    @resource_filter.setter
    def resource_filter(self, value: int):
        """
        :param int value:
        """

        self.tree_tab_setting_att.ResourceFilter = value

    def get_applicative_data_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetApplicativeDataFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Applicative Data"
                |     parameter.
                |     Role:Retrieves the state of the "Applicative Data" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetApplicativeDataFilterInfo(io_admin_level, io_locked)

    def get_assigned_viewer_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAssignedViewerInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Assigned Viewer"
                |     parameter.
                |     Role:Retrieves the state of the "Assigned Viewer" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetAssignedViewerInfo(io_admin_level, io_locked)

    def get_attributes_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttributesFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Attributes"
                |     parameter.
                |     Role:Retrieves the state of the "Attributes" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetAttributesFilterInfo(io_admin_level, io_locked)

    def get_collapse_expand_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCollapseExpandFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Disable Collapse/Expand"
                |     parameter.
                |     Role:Retrieves the state of the "Disable Collapse/Expand" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetCollapseExpandFilterInfo(io_admin_level, io_locked)

    def get_display_name_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayNameModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Display Name Mode"
                |     parameter.
                |     Role:Retrieves the state of the "Display Name Mode" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetDisplayNameModeInfo(io_admin_level, io_locked)

    def get_display_order_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayOrderInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Display Order'
                |     parameter.
                |     Role:Retrieves the state of the 'Display Order' parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetDisplayOrderInfo(io_admin_level, io_locked)

    def get_display_process_order_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayProcessOrderInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Display Order for Processes'
                |     parameter.
                |     Role:Retrieves the state of the 'Display Order for Processes' parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetDisplayProcessOrderInfo(io_admin_level, io_locked)

    def get_items_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetItemsFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Items Folder'
                |     parameter.
                |     Role:Retrieves the state of the 'Items Folder' parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetItemsFilterInfo(io_admin_level, io_locked)

    def get_items_per_relation_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetItemsPerRelationFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Items Folder(Per Relation
                |     Type)' parameter.
                |     Role:Retrieves the state of the 'Items Folder(Per Relation Type)' parameter
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetItemsPerRelationFilterInfo(io_admin_level, io_locked)

    def get_logical_act_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLogicalActFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Logical Activities"
                |     parameter.
                |     Role:Retrieves the state of the "Logical Activities" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetLogicalActFilterInfo(io_admin_level, io_locked)

    def get_output_product_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputProductFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Output Products Folder"
                |     parameter.
                |     Role:Retrieves the state of the "Output Products Folder" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetOutputProductFilterInfo(io_admin_level, io_locked)

    def get_paste_same_instance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPasteSameInstanceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the 'Paste Same Instance'
                |     parameter.
                |     Role:Retrieves the state of the 'Paste Same Instance' parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetPasteSameInstanceInfo(io_admin_level, io_locked)

    def get_render_style_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRenderStyleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Render Style"
                |     parameter.
                |     Role:Retrieves the state of the "Render Style" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetRenderStyleInfo(io_admin_level, io_locked)

    def get_resource_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetResourceFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the 'Resource Folder'
                |     parameter.
                |     Role:Retrieves the state of the 'Resource Folder' parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tree_tab_setting_att.GetResourceFilterInfo(io_admin_level, io_locked)

    def set_applicative_data_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetApplicativeDataFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Applicative Data" parameter.
                |     Role:Locks or unlocks the "Attributes" parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetApplicativeDataFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_applicative_data_filter_lock'
        # # vba_code = """
        # # Public Function set_applicative_data_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetApplicativeDataFilterLock iLocked
        # #     set_applicative_data_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_assigned_viewer_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAssignedViewerLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Assigned Viewer" parameter.
                |     Role:Locks or unlocks the "Assigned Viewer" parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetAssignedViewerLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_assigned_viewer_lock'
        # # vba_code = """
        # # Public Function set_assigned_viewer_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetAssignedViewerLock iLocked
        # #     set_assigned_viewer_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_attributes_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttributesFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Attributes" parameter.
                |     Role:Locks or unlocks the "Attributes" parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetAttributesFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_attributes_filter_lock'
        # # vba_code = """
        # # Public Function set_attributes_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetAttributesFilterLock iLocked
        # #     set_attributes_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_collapse_expand_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCollapseExpandFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Disable Collapse/Expand" parameter.
                |     Role:Locks or unlocks the "Disable Collapse/Expand" parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetCollapseExpandFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_collapse_expand_filter_lock'
        # # vba_code = """
        # # Public Function set_collapse_expand_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetCollapseExpandFilterLock iLocked
        # #     set_collapse_expand_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_name_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayNameModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Display Name Mode" parameter.
                |     Role:Locks or unlocks the "Display Name Mode" parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetDisplayNameModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_name_mode_lock'
        # # vba_code = """
        # # Public Function set_display_name_mode_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetDisplayNameModeLock iLocked
        # #     set_display_name_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_order_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayOrderLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Display Order' parameter.
                |     Role:Locks or unlocks the 'Display Order' parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetDisplayOrderLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_order_lock'
        # # vba_code = """
        # # Public Function set_display_order_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetDisplayOrderLock iLocked
        # #     set_display_order_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_process_order_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayProcessOrderLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Display Order for Processes'
                |     parameter.
                |     Role:Locks or unlocks the 'Display Order for Processes' parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetDisplayProcessOrderLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_process_order_lock'
        # # vba_code = """
        # # Public Function set_display_process_order_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetDisplayProcessOrderLock iLocked
        # #     set_display_process_order_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_items_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetItemsFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Items Folder' parameter.
                |     Role:Locks or unlocks the 'Items Folder' parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetItemsFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_items_filter_lock'
        # # vba_code = """
        # # Public Function set_items_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetItemsFilterLock iLocked
        # #     set_items_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_items_per_relation_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetItemsPerRelationFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Items Folde(Per Relation Type)r'
                |     parameter.
                |     Role:Locks or unlocks the 'Items Folder(Per Relation Type)' parameter if it
                |     is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetItemsPerRelationFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_items_per_relation_filter_lock'
        # # vba_code = """
        # # Public Function set_items_per_relation_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetItemsPerRelationFilterLock iLocked
        # #     set_items_per_relation_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_logical_act_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLogicalActFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Logical Activities" parameter.
                |     Role:Locks or unlocks the "Logical Activities" parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetLogicalActFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_logical_act_filter_lock'
        # # vba_code = """
        # # Public Function set_logical_act_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetLogicalActFilterLock iLocked
        # #     set_logical_act_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_product_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputProductFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Output Products Folder" parameter.
                |     Role:Locks or unlocks the "Output Products Folder" parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetOutputProductFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_product_filter_lock'
        # # vba_code = """
        # # Public Function set_output_product_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetOutputProductFilterLock iLocked
        # #     set_output_product_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_paste_same_instance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPasteSameInstanceLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Paste Same Instance' parameter.
                |     Role:Locks or unlocks the 'Paste Same Instance' parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetPasteSameInstanceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_paste_same_instance_lock'
        # # vba_code = """
        # # Public Function set_paste_same_instance_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetPasteSameInstanceLock iLocked
        # #     set_paste_same_instance_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_render_style_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRenderStyleLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Render Style" parameter.
                |     Role:Locks or unlocks the "Render Style" parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetRenderStyleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_render_style_lock'
        # # vba_code = """
        # # Public Function set_render_style_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetRenderStyleLock iLocked
        # #     set_render_style_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_resource_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetResourceFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the 'Resource Folder' parameter.
                |     Role:Locks or unlocks the 'Resource Folder' parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tree_tab_setting_att.SetResourceFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_resource_filter_lock'
        # # vba_code = """
        # # Public Function set_resource_filter_lock(tree_tab_setting_att)
        # #     Dim iLocked (2)
        # #     tree_tab_setting_att.SetResourceFilterLock iLocked
        # #     set_resource_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TreeTabSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.file import File
from pycatia.system_interfaces.collection import Collection


class Files(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Files
                | 
                | A collection of all the file objects in a folder.
                | It lists all the files contained in the folder. It allows to retrieve File
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=File)
        self.files = com_object

    def item(self, i_number: int) -> File:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iNumber) As File
                | 
                |     Returns a file using its index or its name from the file
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the file to retrieve from the collection
                |             of files. As a numerics, this index is the rank of the file in the collection.
                |             The index of the first file in the collection is 1, and the index of the last
                |             file is Count. As a string, it is the name you assigned to the file using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved file 
                |     Example:
                |         This example retrieves in ThisFile the third file, and it ThatFile the
                |         file named MyFile. in the TestFiles file collection.
                | 
                |          Dim ThisFile As File
                |          Set ThisFile = TestFiles.Item(3)
                |          Dim ThatFile As File
                |          Set ThatFile = TestFiles.Item("MyFile")

        :param int i_number:
        :rtype: File
        """
        return File(self.files.Item(i_number))

    def __getitem__(self, n: int) -> File:
        if (n + 1) > self.count:
            raise StopIteration

        return File(self.files.Item(n + 1))

    def __iter__(self) -> Iterator[File]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Files(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPAttributeReport(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspAttributeReport
                | 
                | Represents the Attribute Report.
                | Role: To generate attributes report.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_attribute_report = com_object

    def generate_report(self, i_input_format_file: str, i_outputfile: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GenerateReport(CATBSTR iInputFormatFile,
                | CATBSTR iOutputfile) As long
                | 
                |     Generate report (output format in html or CSV) and returns the status. It
                |     reports attribute data for all the selected objects in the
                |     document.
                | 
                |     Parameters:
                | 
                |         iInputFormatFile
                |             Attribute report format filename. It should contain the directory
                |             path.
                | 
                |              Note:    
                |                The format file is a text (.txt) file containing data in
                |                following
                |                order.
                |                Title=Title of the report
                |                TextFormat=HTML  or  TextFormat=CSV (Comma separated)
                |                Attrib=AttributeName likes Nominal size,EndStyle, Rating etc.
                |                Len=Integer value indicating length of attribute value
                |                and so on...
                |                Report format sample: Sample.txt
                |                Title=Piping parts report
                |                TextFormat=HTML
                |                Attrib=ID
                |                Len=15
                |                Attrib=Nominal size
                |                Len=10
                |                Attrib=Rating
                |                Len=10
                |                .... and so on  
                |
                |         iOutputfile
                |             Output filename. Full file name of the report output.
                |
                |     Returns:
                |         0 or 1. Legal values:
                |         1 : Report generation failed.
                |         0 : Report generation succeeded.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttributeReport
                |          Dim strVar1 As CATBSTR
                |          Dim StrVar2 As CATBSTR
                |          Dim longRet    As Long
                |           ...
                |          olongRet = objThisIntf.GenerateReport (strVar1,strVar2 )

        :param str i_input_format_file:
        :param str i_outputfile:
        :rtype: int
        """
        return self.psp_attribute_report.GenerateReport(i_input_format_file, i_outputfile)

    def __repr__(self):
        return f'PSPAttributeReport(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_human_sim_interfaces.auto_walk_activity import AutoWalkActivity
from pycatia.dnb_human_sim_interfaces.collision_free_walk import CollisionFreeWalk
from pycatia.dnb_human_sim_interfaces.move_to_posture_activity import MoveToPostureActivity
from pycatia.dnb_human_sim_interfaces.pick_activity import PickActivity
from pycatia.dnb_human_sim_interfaces.place_activity import PlaceActivity
from pycatia.dnb_human_sim_interfaces.walk_activity import WalkActivity
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class HumanActivityGroupFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     HumanActivityGroupFactory
                | 
                | The object that represents the Human Activity Group Factory.
                | 
                | Following activity types could be created using the HumanActivityGroup
                | Factory.
                | MoveToPostureActivity
                | WalkActivity (Forward/Backward/SideStep)
                | AutoWalkActivity
                | PickActivity
                | PlaceActivity
                | CollisionFreeWalkActivity(Forward and Backward)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_activity_group_factory = com_object

    def create_auto_walk(self, i_prev_act: Activity) -> AutoWalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateAutoWalk(Activity iPrevAct) As AutoWalkActivity
                | 
                |     Returns newly created AutoWalkActivity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                | 
                |     Returns:
                |         oCreatedAutoWalk newly created AutoWalkActivity
                |
                |     Example:
                | 
                |         This example creates AutoWalk Activity on Plane
                |
                |        ' Get the Human Acts factory and Human Task List
                |         Dim oHumActsFactory As HumanActsFactory
                |         Dim oHumanTask As HumanTask
                |         Dim iPevAct As Activity
                |         Dim oHT as HumanTask
                |         Dim ActList As Activities
                |         Dim iPrevAct As Activity
                |         Dim oHumTaskList As HumanTaskList
                |         Set oHT = oHumTaskList.Item(1)
                |         Set ActList = oHT.ChildrenActivities
                |         Set iPrevAct = ActList.Item(2) ' MoveToPosture.1
                |         Dim oCreatedAutoWalk as AutoWalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create AutoWalk Activity
                |            Set oCreatedAutoWalk = oHumActsFactory.CreateAutoWalk(iPrevAct)

        :param Activity i_prev_act:
        :rtype: AutoWalkActivity
        """
        return AutoWalkActivity(self.human_activity_group_factory.CreateAutoWalk(i_prev_act.com_object))

    def create_collision_free_walk_bwd_on_arr_area(
            self,
            i_prev_act: Activity,
            i_arr_area: Product,
            i_num_points: int,
            i_search_int: int,
            i_clearence: float,
            i_points: tuple
    ) -> CollisionFreeWalk:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCollisionFreeWalkBwdOnArrArea(Activity
                | iPrevAct,
                | Product iArrArea,
                | long iNumPoints,
                | HTSSearchIntensity iSearchInt,
                | double iClearence,
                | CATSafeArrayVariant iPoints) As CollisionFreeWalk
                | 
                |     Returns newly created Collision free Walk Backward Activity on Arrangement
                |     Area.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iArrArea
                |             Arrangment Area - Plane of Walk 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path 
                |         iSearchInt
                |             (see 
                | 
                |         HTSSearchIntensity for list of possible values) 
                |     iClearance
                |         The clearance value to be used for detecting collision between objects
                |         
                |     iPoints
                |         Point values x1,y1,z1 , x2,y2,z2, .... in iArrArea coordinates
                |         
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |              This example creates WalkBackward Activity on Arrangement
                |              Area
                |
                |         ' From the ProductList get the Arrangement Area
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Dim prodAreasFather As Product
                |         Dim prodAreaFathersChildren As Products
                | 
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set prodAreasFather = pprprodsProdList.Item(1)
                |         Set prodAreaFathersChildren = prodAreasFather.Products
                | 
                |         Dim iArrArea As Product
                |         Set iArrArea = prodAreaFathersChildren.GetItem("Area1.1")
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |        ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as DNBIACollisionFreeWalk
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create Collision free WalkBackward Activity on Arrangement
                |            area
                |            Set oCreatedWalk = oHumActsFactory.CreateCollisionFreeWalkBwdOnArrArea(iPrevAct, iArrArea, iNumPoints, iSearchInt, iClearance, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_arr_area:
        :param int i_num_points:
        :param int i_search_int: enum hts_search_intensity
        :param float i_clearence:
        :param tuple i_points:
        :rtype: CollisionFreeWalk
        """
        return CollisionFreeWalk(
            self.human_activity_group_factory.CreateCollisionFreeWalkBwdOnArrArea(
                i_prev_act.com_object,
                i_arr_area.com_object,
                i_num_points,
                i_search_int,
                i_clearence,
                i_points
            )
        )

    def create_collision_free_walk_bwd_on_plane(
            self,
            i_prev_act: Activity,
            i_plane_prod: Product,
            i_plane_def: tuple,
            i_num_points: int,
            i_search_int: int,
            i_clearence: float,
            i_points: tuple
    ) -> CollisionFreeWalk:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCollisionFreeWalkBwdOnPlane(Activity iPrevAct,
                | Product iPlaneProd,
                | CATSafeArrayVariant iPlaneDef,
                | long iNumPoints,
                | HTSSearchIntensity iSearchInt,
                | double iClearence,
                | CATSafeArrayVariant iPoints) As CollisionFreeWalk
                | 
                |     Returns newly created Collision free Walk Backward
                |     Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlaneProd
                |             Handle to Product 
                |         iPlaneDef
                |             Walk Plane definition - 9 doubles FirstAxis(i,j,k),
                |             SecondAxis(i,j,k), OriginOfPlane(x,y,z) in iPlaneProd Coordinates
                |             
                |         iNumPoints
                |         iSearchInt
                |             (see HTSSearchIntensity for list of possible values)
                |     iClearance
                |         The clearance value to be used for detecting collision between objects
                |         Number of Coplanar-Points defining the Walk Path in Plane
                |         
                |     iPoints
                |         Point values x1,y1,z1 , x2,y2,z2, .... iPlaneDef coordinates
                |         
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |         This example creates WalkBackward Activity on Plane
                |
                |         ' From the ProductList get the Walk Plane product
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Dim oPlaneProd As Product
                |         Set oPlaneProd = pprprodsProdList.Item(2)
                | 
                |         ' Plane Definition.. w.r.to Product
                | 
                |         Dim iPlaneDef(9) as Double
                |         iPlaneDef(0) = 1.0         ' First Axis  - i vec
                |         iPlaneDef(1) = 0.0         ' First Axis  - j vec
                |         iPlaneDef(2) = 0.0         ' First Axis  - k vec
                |         iPlaneDef(3) = 0.0         ' Second Axis - i vec
                |         iPlaneDef(4) = 1.0         ' Second Axis - j vec
                |         iPlaneDef(5) = 0.0         ' Second Axis - k vec
                |         iPlaneDef(6) = 0.0         ' Origin      - X
                |         iPlaneDef(7) = 0.0         ' Origin      - Y
                |         iPlaneDef(8) = 0.0         ' Origin      - Z
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as DNBIACollisionFreeWalk
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create Collision free WalkBackward Activity on
                |            Plane
                |            Set oCreatedWalk = oHumActsFactory.CreateCollisionFreeWalkBwdOnPlane(iPrevAct,
                |                                                                                 iPlaneProd,
                |                                                                                 iPlaneDef,
                |                                                                                 iNumPoints,
                |                                                                                 iSearchInt,
                |                                                                                 iClearance,
                |                                                                                 iPoints)
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_plane_prod:
        :param tuple i_plane_def:
        :param int i_num_points:
        :param int i_search_int: enum hts_search_intensity
        :param float i_clearence:
        :param tuple i_points:
        :rtype: CollisionFreeWalk
        """
        return CollisionFreeWalk(
            self.human_activity_group_factory.CreateCollisionFreeWalkBwdOnPlane(
                i_prev_act.com_object,
                i_plane_prod.com_object,
                i_plane_def,
                i_num_points,
                i_search_int,
                i_clearence,
                i_points
            )
        )

    def create_collision_free_walk_fwd_on_arr_area(
            self,
            i_prev_act: Activity,
            i_arr_area: Product,
            i_num_points: int,
            i_search_int: int,
            i_clearence: float,
            i_points: tuple
    ) -> CollisionFreeWalk:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCollisionFreeWalkFwdOnArrArea(Activity
                | iPrevAct,
                | Product iArrArea,
                | long iNumPoints,
                | HTSSearchIntensity iSearchInt,
                | double iClearence,
                | CATSafeArrayVariant iPoints) As CollisionFreeWalk
                | 
                |     Returns newly created Collision free Walk Forward
                |     Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             Previous Activity 
                |         iArrArea
                |             Arrangment Area - Plane of Walk 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path 
                |         iSearchInt
                |             (see 
                | 
                |         HTSSearchIntensity for list of possible values) 
                |     iClearance
                |         The clearance value to be used for detecting collision between objects
                |         
                |     iPoints
                |         Point values x1,y1,z1 , x2,y2,z2, .... in iArrArea coordinates
                |         
                |     Returns:
                |         oCreatedWalk Newly created WalkActivity 
                |     Example:
                | 
                |              This example creates Collision free WalkForward Activity on
                |              Arrangement Area
                |
                |         ' From the ProductList get the Arrangement Area
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Dim prodAreasFather As Product
                |         Dim prodAreaFathersChildren As Products
                | 
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set prodAreasFather = pprprodsProdList.Item(1)
                |         Set prodAreaFathersChildren = prodAreasFather.Products
                | 
                |         Dim iArrArea As Product
                |         Set iArrArea = prodAreaFathersChildren.GetItem("Area1.1")
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as DNBIACollisionFreeWalk
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                |         Dim iClearance as Double
                |         iClearance = 170
                |         Dim iSearchInt as Long
                |         iSearchInt = 1
                | 
                |            ' Create Collision free WalkForward Activity on Arrangement
                |            area
                |            Set oCreatedWalk = oHumActsFactory.CreateCollisionFreeWalkFwdOnArrArea(iPrevAct, iArrArea, iNumPoints, iSearchInt, iClearance, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_arr_area:
        :param int i_num_points:
        :param int i_search_int: enum hts_search_intensity
        :param float i_clearence:
        :param tuple i_points:
        :rtype: CollisionFreeWalk
        """
        return CollisionFreeWalk(
            self.human_activity_group_factory.CreateCollisionFreeWalkFwdOnArrArea(
                i_prev_act.com_object,
                i_arr_area.com_object,
                i_num_points,
                i_search_int,
                i_clearence,
                i_points
            )
        )

    def create_collision_free_walk_fwd_on_plane(
            self,
            i_prev_act: Activity,
            i_plane_prod: Product,
            i_plane_def: tuple,
            i_num_points: int,
            i_search_int: int,
            i_clearence: float,
            i_points: tuple
    ) -> CollisionFreeWalk:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCollisionFreeWalkFwdOnPlane(Activity iPrevAct,
                | Product iPlaneProd,
                | CATSafeArrayVariant iPlaneDef,
                | long iNumPoints,
                | HTSSearchIntensity iSearchInt,
                | double iClearence,
                | CATSafeArrayVariant iPoints) As CollisionFreeWalk
                | 
                |     Returns newly created Collision free Walk Forward Activity
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlaneProd
                |             Handle to Walk plane product 
                |         iPlaneDef
                |             Walk Plane definition - 9 doubles FirstAxis(i,j,k),
                |             SecondAxis(i,j,k), OriginOfPlane(x,y,z) in iPlaneProd Coordinates
                |             
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path in Plane
                |             
                |         iSearchInt
                |             (see 
                | 
                |         HTSSearchIntensity for list of possible values) 
                |     iClearance
                |         The clearance value to be used for detecting collision between objects
                |         
                |     iPoints
                |         Point values x1,y1,z1 , x2,y2,z2, .... iPlaneDef coordinates
                |         
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |              This example creates WalkForward Activity on Plane
                |
                |         ' From the ProductList get the Walk Plane product
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Dim oPlaneProd As Product
                |         Set oPlaneProd = pprprodsProdList.Item(2)
                | 
                |         ' Plane Definition.. w.r.to Product
                | 
                |         Dim iPlaneDef(9) as Double
                |         iPlaneDef(0) = 1.0         ' First Axis  - i vec
                |         iPlaneDef(1) = 0.0         ' First Axis  - j vec
                |         iPlaneDef(2) = 0.0         ' First Axis  - k vec
                |         iPlaneDef(3) = 0.0         ' Second Axis - i vec
                |         iPlaneDef(4) = 1.0         ' Second Axis - j vec
                |         iPlaneDef(5) = 0.0         ' Second Axis - k vec
                |         iPlaneDef(6) = 0.0         ' Origin      - X
                |         iPlaneDef(7) = 0.0         ' Origin      - Y
                |         iPlaneDef(8) = 0.0         ' Origin      - Z
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as DNBIACollisionFreeWalk
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create Collision free WalkForward Activity on
                |            Plane
                |            Set oCreatedWalk = oHumActsFactory.CreateCollisionFreeWalkFwdOnPlane(iPrevAct, iPlaneProd, iPlaneDef, iNumPoints, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_plane_prod:
        :param tuple i_plane_def:
        :param int i_num_points:
        :param int i_search_int: enum hts_search_intensity
        :param float i_clearence:
        :param tuple i_points:
        :rtype: CollisionFreeWalk
        """
        return CollisionFreeWalk(
            self.human_activity_group_factory.CreateCollisionFreeWalkFwdOnPlane(
                i_prev_act.com_object,
                i_plane_prod.com_object,
                i_plane_def,
                i_num_points,
                i_search_int,
                i_clearence,
                i_points
            )
        )

    def create_move_to_posture(self, i_prev_act: Activity) -> MoveToPostureActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateMoveToPosture(Activity iPrevAct) As
                | MoveToPostureActivity
                | 
                |     Returns newly created MoveToPostureActivity.
                |     Current posture of Manikin is set as joint-values for created
                |     MoveToPostureActivity. Use MoveToPostureActivity APIs to change
                |     joint-values.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                | 
                |     Returns:
                |         oCreatedMTP newly created MoveToPostureActivity
                |
                |     Example:
                | 
                |              This example creates MoveToPosture Activity 
                |
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedMTP as MoveToPostureActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create MoveToPosture Activity
                |            Set oCreatedMTP = oHumActsFactory.CreateMoveToPosture(iPrevAct) 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :rtype: MoveToPostureActivity
        """
        return MoveToPostureActivity(self.human_activity_group_factory.CreateMoveToPosture(i_prev_act.com_object))

    def create_pick(
            self,
            i_prev_act: Activity,
            i_pick_type: int,
            b_create_cst_with_picking_hand: bool,
            i_picking_hand: int,
            i_picked_products: tuple
    ) -> PickActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreatePick(Activity iPrevAct,
                | HTSPickType iPickType,
                | boolean bCreateCstWithPickingHand,
                | HTSHand iPickingHand,
                | CATSafeArrayVariant iPickedProducts) As PickActivity
                | 
                |     Returns newly created Pick Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPickType
                |             Pick Type: SINGLE_HAND or BOTH_HANDS 
                |         bCreateCstWithPickingHand
                |             Boolean flag to indicate whether constraint has to be created
                |             between the picked object and picking hand 
                |         iPickingHand
                |             picking hand: HAND_RIGHT or HAND_LEFT 
                |         iPickedProducts
                |             List of picked products 
                | 
                |     Returns:
                |         oCreatedPick newly created PickActivity 
                |     Example:
                | 
                |              This example creates Pick Activity
                |
                |         ' Get the Human Acts factory and Human Task List
                |         Dim oHumActsFactory As HumanActsFactory
                |         Dim oHumanTask As HumanTask
                |         Dim oHT as HumanTask
                |         Dim ActList As Activities
                |         Dim iPrevAct As Activity
                |         Dim oHumTaskList As HumanTaskList
                |         Set oHT = oHumTaskList.Item(1)
                |         Set ActList = oHT.ChildrenActivities
                |         Set iPrevAct = ActList.Item(2) ' MoveToPosture.1
                |         Dim oCreatedPick as PickActivity
                |            ....
                |         ' Specify the picked products
                |         Dim iPickedProds(1) As AnyObject
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set iPickedProducts = pprprodsProdList.Item(2)
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create Pick Activity
                |            Set oCreatePick = oHumActsFactory.CreatePick(iPrevAct,SINGLE_HAND, TRUE, HAND_RIGHT, iPickedProducts)

        :param Activity i_prev_act:
        :param int i_pick_type: enum hts_pick_type
        :param bool b_create_cst_with_picking_hand:
        :param int i_picking_hand: enum hts_hand
        :param tuple i_picked_products:
        :rtype: PickActivity
        """
        return PickActivity(
            self.human_activity_group_factory.CreatePick(
                i_prev_act.com_object,
                i_pick_type,
                b_create_cst_with_picking_hand,
                i_picking_hand,
                i_picked_products
            )
        )

    def create_place(self, i_prev_act: Activity, i_picked_products: tuple, i_offset: tuple) -> PlaceActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreatePlace(Activity iPrevAct,
                | CATSafeArrayVariant iPickedProducts,
                | CATSafeArrayVariant iOffset) As PlaceActivity
                | 
                |     Returns newly created Place Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlacedProducts
                |             List of products to be placed 
                |         iPlaceOffset
                |             Offset to be maintainted between the placing hand and the object.
                |             The offset has to be specified as the relative trnsformation between the
                |             placing hand and the object to be placed. The first 9 entries correspond to the
                |             rotation matrix and the next 3 entries correspond to the position
                |             vector.
                |             R1x R1y R1z
                |             R2x R2y R2z
                |             R3x R3y R3z
                |             Px Py Pz
                |             R1x:x-component of x axis
                |             R2x:y-component of x axis
                |             R3x:z-component of x axis
                |             R1y:x-component of y axis
                |             R2y:y-component of y axis
                |             R3y:z-component of y axis
                |             R1z:x-component of z axis
                |             R2z:y-component of z axis
                |             R3z:z-component of z axis
                | 
                |     Returns:
                |         oCreatedPlace Newly created PlaceActivity 
                |     Example:
                | 
                |              This example creates Place Activity
                |
                |         ' Get the Human Acts factory and Human Task List
                |         Dim oHumActsFactory As HumanActsFactory
                |         Dim oHumanTask As HumanTask
                |         Dim oHT as HumanTask
                |         Dim ActList As Activities
                |         Dim iPrevAct As Activity
                |         Dim oHumTaskList As HumanTaskList
                |         Set oHT = oHumTaskList.Item(1)
                |         Set ActList = oHT.ChildrenActivities
                |         Set iPrevAct = ActList.Item(2) ' MoveToPosture.1
                |         Dim oCreatedPlace as Placectivity
                |            ....
                |         ' Get the list of picked products from the Pick
                |         Activity
                |         Dim iPickedProducts As AnyObject
                |          'Example of 45 degree rotation around the x-axis of placing
                |          hand
                |         Dim iPlaceOffset(12) As Double ' 12 doubles - 0 to 11; relative
                |         transformation between hand and object 
                |         ' X axis rotation component
                |         iPlaceOffset( 0 )  = 1
                |         iPlaceOffset( 3 )  = 0
                |         iPlaceOffset( 6 )  = 0
                |         ' Y axis rotation component
                |         iPlaceOffset( 1 )  =0
                |         iPlaceOffset( 4 )  =0.707
                |         iPlaceOffset( 7 )  = 0.707
                |         ' Z axis rotation component
                |         iPlaceOffset( 2 )  = 0
                |         iPlaceOffset( 5 ) = -0.707
                |         iPlaceOffset( 8 ) = 0.707
                |         ' position vector (relative vector between the hand and
                |         object)
                |         iPlaceOffset( 9 )  = 0
                |         iPlaceOffset( 10 )  = 0
                |         iPlaceOffset( 11 )  = 0
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create Place Activity
                |            Set oCreatedPlace = oHumActsFactory.CreatePlace(iPrevAct,iPickedProducts, iPlaceOffset);

        :param Activity i_prev_act:
        :param tuple i_picked_products:
        :param tuple i_offset:
        :rtype: PlaceActivity
        """
        return PlaceActivity(
            self.human_activity_group_factory.CreatePlace(
                i_prev_act.com_object,
                i_picked_products,
                i_offset
            )
        )

    def create_side_step_on_arr_area(
            self,
            i_prev_act: Activity,
            i_arr_area: Product,
            i_start_pt: tuple,
            i_end_pt: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSideStepOnArrArea(Activity iPrevAct,
                | Product iArrArea,
                | CATSafeArrayVariant iStartPt,
                | CATSafeArrayVariant iEndPt) As WalkActivity
                | 
                |     Returns newly created Side-Step Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iArrArea
                |             Arrangment Area - Plane of Walk 
                |         iStartPt
                |             Start Point - x,y,z in iArrArea coordinates 
                |         iEndPt
                |             End Point - x,y,z in iArrArea coordinates 
                | 
                |     Returns:
                |         oCreatedWalk newly created WalkActivity
                | 
                |         ' From the ProductList get the Arrangement Area
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Dim prodAreasFather As Product
                |         Dim prodAreaFathersChildren As Products
                | 
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set prodAreasFather = pprprodsProdList.Item(1)
                |         Set prodAreaFathersChildren = prodAreasFather.Products
                | 
                |         Dim iArrArea As Product
                |         Set iArrArea = prodAreaFathersChildren.GetItem("Area1.1")
                | 
                |         ' Specify the Start and End  points for the side step walk
                |         activity
                |         Dim iStart(3) as Double
                |         Dim iEnd(3) as Double
                |         iStart(0) = 0
                |         iStart(1) = 0
                |         iStart(2) = 0.0
                |         iEnd(0) = 2000
                |         iEnd(1) = 0
                |         iEnd(2) = 0.0
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create SideStep Activity on Arrangement area
                |            oCreatedWalk = oHumActsFactory.CreateSideStepOnArrArea(iPrevAct, iArrArea, iStartPt, iEndPt) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update

        :param Activity i_prev_act:
        :param Product i_arr_area:
        :param tuple i_start_pt:
        :param tuple i_end_pt:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateSideStepOnArrArea(
                i_prev_act.com_object,
                i_arr_area.com_object,
                i_start_pt,
                i_end_pt
            )
        )

    def create_side_step_on_plane(
            self,
            i_prev_act: Activity,
            i_plane_prod: Product,
            i_plane_def: tuple,
            i_start_pt: tuple,
            i_end_pt: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSideStepOnPlane(Activity iPrevAct,
                | Product iPlaneProd,
                | CATSafeArrayVariant iPlaneDef,
                | CATSafeArrayVariant iStartPt,
                | CATSafeArrayVariant iEndPt) As WalkActivity
                | 
                |     Returns newly created Side-Step Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlaneProd
                |             Handle to Product 
                |         iPlaneDef
                |             Walk Plane definition - 9 doubles FirstAxis(i,j,k),
                |             SecondAxis(i,j,k), OriginOfPlane(x,y,z) in oCGRProd Coordinates
                |             
                |         iStartPt
                |             Start Point - x,y,z in iPlaneDef coordinates 
                |         iEndPt
                |             End Point - x,y,z in iPlaneDef coordinates 
                | 
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |              This example creates SideStep Activity on Plane 
                |
                |         ' From the ProductList get the Walk Plane product
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Dim oPlaneProd As Product
                |         Set oPlaneProd = pprprodsProdList.Item(2)
                | 
                |         ' Plane Definition.. w.r.to Product
                | 
                |         Dim adPlaneDef(9) as Double
                |         adPlaneDef(0) = 1.0         ' First Axis  - i vec
                |         adPlaneDef(1) = 0.0         ' First Axis  - j vec
                |         adPlaneDef(2) = 0.0         ' First Axis  - k vec
                |         adPlaneDef(3) = 0.0         ' Second Axis - i vec
                |         adPlaneDef(4) = 1.0         ' Second Axis - j vec
                |         adPlaneDef(5) = 0.0         ' Second Axis - k vec
                |         adPlaneDef(6) = 0.0         ' Origin      - X
                |         adPlaneDef(7) = 0.0         ' Origin      - Y
                |         adPlaneDef(8) = 0.0         ' Origin      - Z
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim adStart(3) as Double
                |         Dim adEnd(3) as Double
                |         adStart(0) = 0
                |         adStart(1) = 0
                |         adStart(2) = 0.0
                |         adEnd(0) = 2000
                |         adEnd(1) = 0
                |         adEnd(2) = 0.0
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPeviousActivity As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create SideStep Activity on Plane
                |            oCreatedWalk = oHumActsFactory.CreateSideStepOnPlane(iPrevAct, iPlaneProd, iPlaneDef, iStartPt, iEndPt) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_plane_prod:
        :param tuple i_plane_def:
        :param tuple i_start_pt:
        :param tuple i_end_pt:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateSideStepOnPlane(
                i_prev_act.com_object,
                i_plane_prod.com_object,
                i_plane_def,
                i_start_pt,
                i_end_pt
            )
        )

    def create_walk_bwd_on_arr_area(
            self,
            i_prev_act: Activity,
            i_arr_area: Product,
            i_num_points: int,
            i_points: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateWalkBwdOnArrArea(Activity iPrevAct,
                | Product iArrArea,
                | long iNumPoints,
                | CATSafeArrayVariant iPoints) As WalkActivity
                | 
                |     Returns newly created Walk Backward Activity on Arrangement
                |     Area.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iArrArea
                |             Arrangment Area - Plane of Walk 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path 
                |         iPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... in iArrArea coordinates
                |
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |              This example creates WalkBackward Activity on Arrangement
                |              Area
                |
                |         ' From the ProductList get the Arrangement Area
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Dim prodAreasFather As Product
                |         Dim prodAreaFathersChildren As Products
                | 
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set prodAreasFather = pprprodsProdList.Item(1)
                |         Set prodAreaFathersChildren = prodAreasFather.Products
                | 
                |         Dim iArrArea As Product
                |         Set iArrArea = prodAreaFathersChildren.GetItem("Area1.1")
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create WalkBackward Activity on Arrangement area
                |            Set oCreatedWalk = oHumActsFactory.CreateWalkBwdOnArrArea(iPrevAct, iArrArea, iNumPoints, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_arr_area:
        :param int i_num_points:
        :param tuple i_points:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateWalkBwdOnArrArea(
                i_prev_act.com_object,
                i_arr_area.com_object,
                i_num_points,
                i_points
            )
        )

    def create_walk_bwd_on_plane(
            self,
            i_prev_act: Activity,
            i_plane_prod: Product,
            i_plane_def: tuple,
            i_num_points: int,
            i_points: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateWalkBwdOnPlane(Activity iPrevAct,
                | Product iPlaneProd,
                | CATSafeArrayVariant iPlaneDef,
                | long iNumPoints,
                | CATSafeArrayVariant iPoints) As WalkActivity
                | 
                |     Returns newly created Walk Backward Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlaneProd
                |             Handle to Product 
                |         iPlaneDef
                |             Walk Plane definition - 9 doubles FirstAxis(i,j,k),
                |             SecondAxis(i,j,k), OriginOfPlane(x,y,z) in iPlaneProd Coordinates
                |             
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path in Plane
                |             
                |         iPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... iPlaneDef coordinates
                |             
                | 
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |         This example creates WalkBackward Activity on Plane
                |
                |         ' From the ProductList get the Walk Plane product
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Dim oPlaneProd As Product
                |         Set oPlaneProd = pprprodsProdList.Item(2)
                | 
                |         ' Plane Definition.. w.r.to Product
                | 
                |         Dim iPlaneDef(9) as Double
                |         iPlaneDef(0) = 1.0         ' First Axis  - i vec
                |         iPlaneDef(1) = 0.0         ' First Axis  - j vec
                |         iPlaneDef(2) = 0.0         ' First Axis  - k vec
                |         iPlaneDef(3) = 0.0         ' Second Axis - i vec
                |         iPlaneDef(4) = 1.0         ' Second Axis - j vec
                |         iPlaneDef(5) = 0.0         ' Second Axis - k vec
                |         iPlaneDef(6) = 0.0         ' Origin      - X
                |         iPlaneDef(7) = 0.0         ' Origin      - Y
                |         iPlaneDef(8) = 0.0         ' Origin      - Z
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create WalkBackward Activity on Plane
                |            Set oCreatedWalk = oHumActsFactory.CreateWalkBwdOnPlane(iPrevAct, iPlaneProd, iPlaneDef, iNumPoints, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_plane_prod:
        :param tuple i_plane_def:
        :param int i_num_points:
        :param tuple i_points:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateWalkBwdOnPlane(
                i_prev_act.com_object,
                i_plane_prod.com_object,
                i_plane_def,
                i_num_points,
                i_points
            )
        )

    def create_walk_fwd_on_arr_area(
            self,
            i_prev_act: Activity,
            i_arr_area: Product,
            i_num_points: int,
            i_points: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateWalkFwdOnArrArea(Activity iPrevAct,
                | Product iArrArea,
                | long iNumPoints,
                | CATSafeArrayVariant iPoints) As WalkActivity
                | 
                |     Returns newly created Walk Forward Activity.
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iArrArea
                |             Arrangment Area - Plane of Walk 
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path 
                |         iPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... in iArrArea coordinates
                |
                |     Returns:
                |         oCreatedWalk newly created WalkActivity
                |
                |     Example:
                | 
                |              This example creates WalkForward Activity on Arrangement
                |              Area
                |
                |         ' From the ProductList get the Arrangement Area
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Dim prodAreasFather As Product
                |         Dim prodAreaFathersChildren As Products
                | 
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Set prodAreasFather = pprprodsProdList.Item(1)
                |         Set prodAreaFathersChildren = prodAreasFather.Products
                | 
                |         Dim iArrArea As Product
                |         Set iArrArea = prodAreaFathersChildren.GetItem("Area1.1")
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create WalkForward Activity on Arrangement area
                |            Set oCreatedWalk = oHumActsFactory.CreateWalkFwdOnArrArea(iPrevAct, iArrArea, iNumPoints, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_arr_area:
        :param int i_num_points:
        :param tuple i_points:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateWalkFwdOnArrArea(
                i_prev_act.com_object,
                i_arr_area.com_object,
                i_num_points,
                i_points
            )
        )

    def create_walk_fwd_on_plane(
            self,
            i_prev_act: Activity,
            i_plane_prod: Product,
            i_plane_def: tuple,
            i_num_points: int,
            i_points: tuple
    ) -> WalkActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateWalkFwdOnPlane(Activity iPrevAct,
                | Product iPlaneProd,
                | CATSafeArrayVariant iPlaneDef,
                | long iNumPoints,
                | CATSafeArrayVariant iPoints) As WalkActivity
                | 
                |     Returns newly created Walk Forward Activity
                | 
                |     Parameters:
                | 
                |         iPrevAct
                |             previous activity 
                |         iPlaneProd
                |             Handle to Walk plane product 
                |         iPlaneDef
                |             Walk Plane definition - 9 doubles FirstAxis(i,j,k),
                |             SecondAxis(i,j,k), OriginOfPlane(x,y,z) in iPlaneProd Coordinates
                |             
                |         iNumPoints
                |             Number of Coplanar-Points defining the Walk Path in Plane
                |             
                |         iPoints
                |             Point values x1,y1,z1 , x2,y2,z2, .... iPlaneDef coordinates
                |
                |     Returns:
                |         oCreatedWalk newly created WalkActivity 
                |     Example:
                | 
                |              This example creates WalkForward Activity on Plane
                |
                |         ' From the ProductList get the Walk Plane product
                |         Dim oPPRDoc As PPRDocument
                |         Dim pprprodsProdList As PPRProducts
                |         Set oPPRDoc = DELMIA.ActiveDocument.PPRDocument
                |         Set pprprodsProdList = oPPRDoc.Products
                |         Dim oPlaneProd As Product
                |         Set oPlaneProd = pprprodsProdList.Item(2)
                | 
                |         ' Plane Definition.. w.r.to Product
                | 
                |         Dim iPlaneDef(9) as Double
                |         iPlaneDef(0) = 1.0         ' First Axis  - i vec
                |         iPlaneDef(1) = 0.0         ' First Axis  - j vec
                |         iPlaneDef(2) = 0.0         ' First Axis  - k vec
                |         iPlaneDef(3) = 0.0         ' Second Axis - i vec
                |         iPlaneDef(4) = 1.0         ' Second Axis - j vec
                |         iPlaneDef(5) = 0.0         ' Second Axis - k vec
                |         iPlaneDef(6) = 0.0         ' Origin      - X
                |         iPlaneDef(7) = 0.0         ' Origin      - Y
                |         iPlaneDef(8) = 0.0         ' Origin      - Z
                | 
                |         ' Specify the number of coplanar points defining the walk
                |         path
                |         Dim iNumPoints as Long
                |         iNumPoints = 2
                | 
                |         ' Specify the point values for the walk path in oArrArea
                |         co-ordinates
                |         Dim iPoints(6) as Double
                |         iPoints(0) = 0.0         ' Point1 - X
                |         iPoints(1) = 0.0         ' Point1 - Y
                |         iPoints(2) = 0.0         ' Point1 - Z
                |         iPoints(3) = 2000.0      ' Point2 - X
                |         iPoints(4) = 0.0         ' Point2 - Y
                |         iPoints(5) = 0.0         ' Point2 - Z
                | 
                |            ' Get the Human Acts factory
                |         Dim oHumActsFactory As HumanActsFactory
                |            Dim oHumanTask As HumanTask
                |            Dim iPrevAct As Activity
                |         Dim oCreatedWalk as WalkActivity
                |            ....
                |            ....
                |            Set oHumActsFactory = oHumanTask.GetTechnologicalObject("HumanActsFactory")
                | 
                |            ' Create WalkForward Activity on Plane
                |            Set oCreatedWalk = oHumActsFactory.CreateWalkFwdOnPlane(iPrevAct, iPlaneProd, iPlaneDef, iNumPoints, iPoints) 
                |         ' Generate constituting MTPs
                |         oCreatedWalk.Update 
                |            ....
                |            ....

        :param Activity i_prev_act:
        :param Product i_plane_prod:
        :param tuple i_plane_def:
        :param int i_num_points:
        :param tuple i_points:
        :rtype: WalkActivity
        """
        return WalkActivity(
            self.human_activity_group_factory.CreateWalkFwdOnPlane(
                i_prev_act.com_object,
                i_plane_prod.com_object,
                i_plane_def,
                i_num_points,
                i_points
            )
        )

    def __repr__(self):
        return f'HumanActivityGroupFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.funct_scripts import FunctScripts
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet


class FunctGenScriptMgr(FunctionalFacet):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalFacet
                |                         FunctGenScriptMgr
                | 
                | The interface to access a Functional GenerativeScripts
                | manager.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.funct_gen_script_mgr = com_object

    @property
    def current_script(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CurrentScript() As long
                | 
                |     Get the CurrentScript.

        :rtype: int
        """

        return self.funct_gen_script_mgr.CurrentScript

    @current_script.setter
    def current_script(self, value: int):
        """
        :param int value:
        """

        self.funct_gen_script_mgr.CurrentScript = value

    @property
    def scripts(self) -> FunctScripts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Scripts() As FunctScripts (Read Only)
                | 
                |     Get the Generative Scripts collection.

        :rtype: FunctScripts
        """

        return FunctScripts(self.funct_gen_script_mgr.Scripts)

    def __repr__(self):
        return f'FunctGenScriptMgr(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_item_reservation import ArrangementItemReservation
from pycatia.in_interfaces.move import Move
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementItemReservations(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementItemReservations
                | 
                | A collection object for ArrangementItemReservation objects.
                | Role: Use this collection object to manage (create, retrieve and remove)
                | ArrangementItemReservation objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementItemReservation)
        self.arrangement_item_reservations = com_object

    def add_item_reservation(
            self,
            i_rel_axis: Move,
            i_position: tuple,
            i_x_min: float,
            i_y_min: float,
            i_z_min: float,
            i_x_max: float,
            i_y_max: float,
            i_z_max: float
    ) -> ArrangementItemReservation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddItemReservation(Move iRelAxis,
                | CATSafeArrayVariant iPosition,
                | double iXMin,
                | double iYMin,
                | double iZMin,
                | double iXMax,
                | double iYMax,
                | double iZMax) As ArrangementItemReservation
                | 
                |     Creates an ArrangementItemReservation and adds it to the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             Relative Axis to be considered. 
                |         iPosition
                |             Position information for the ItemReservation (rotation and
                |             location). 
                |         iXMin
                |             Minium X Coordinate of the bounding box on the Item Reservation.
                |             
                |         iYMin
                |             Minium Y Coordinate of the bounding box on the Item Reservation.
                |             
                |         iZMin
                |             Minium Z Coordinate of the bounding box on the Item Reservation.
                |             
                |         iXMax
                |             Maximum X Coordinate of the bounding box on the Item Reservation.
                |             
                |         iYMax
                |             Maximum Y Coordinate of the bounding box on the Item Reservation.
                |             
                |         iZMax
                |             Maximum Z Coordinate of the bounding box on the Item Reservation.
                |             
                | 
                |     Returns:
                |         Returns the newly created ArrangementItemReservation object and adds it
                |         to the collection.

        :param Move i_rel_axis:
        :param tuple i_position:
        :param float i_x_min:
        :param float i_y_min:
        :param float i_z_min:
        :param float i_x_max:
        :param float i_y_max:
        :param float i_z_max:
        :rtype: ArrangementItemReservation
        """
        return ArrangementItemReservation(
            self.arrangement_item_reservations.AddItemReservation(
                i_rel_axis.com_object,
                i_position,
                i_x_min,
                i_y_min,
                i_z_min,
                i_x_max,
                i_y_max,
                i_z_max
            )
        )

    def item(self, i_index: cat_variant) -> ArrangementItemReservation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementItemReservation
                | 
                |     Returns the specified ArrangementItemReservation item of the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementItemReservation to retrieve
                |             from this collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementItemReservation in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementItemReservation by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementItemReservation object.

        :param cat_variant i_index:
        :rtype: ArrangementItemReservation
        """
        return ArrangementItemReservation(self.arrangement_item_reservations.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified ArrangementItemReservation object from the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementItemReservation to remove
                |             from this collection.
                | 
                |             To remove a specific object by number, use the rank of the
                |             ArrangementItemReservation in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To remove a specific
                |                 ArrangementItemReservation by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.arrangement_item_reservations.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(arrangement_item_reservations)
        # #     Dim iIndex (2)
        # #     arrangement_item_reservations.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementItemReservations(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPListOfBSTRs(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspListOfBSTRs
                | 
                | Represents a collection of CATBSTR type of strings.
                | Role: Collection of CATBSTR type of strings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_list_of_bst_rs = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the number of character strings in the list.
                | 
                |     Example:
                |         This example retrieves in NumberOfStrings the number of character
                |         strings currently gathered in MyList.
                | 
                |          Dim NumberOfStrings As long
                |          NumberOfStrings = MyList.Count

        :rtype: int
        """

        return self.psp_list_of_bst_rs.Count

    def append(self, i_bstr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Append(CATBSTR iBSTR)
                | 
                |     Adds a character string to the end of the list.
                | 
                |     Parameters:
                | 
                |         iBSTR
                |             The character string to be added to the list. 
                | 
                |     Example:
                | 
                |           The following example appends a string to the list.
                |
                |          Dim MyList As PspListOfBSTRs
                |          MyList.Append("MyString")

        :param str i_bstr:
        :rtype: None
        """
        return self.psp_list_of_bst_rs.Append(i_bstr)

    def item(self, i_index: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(long iIndex) As CATBSTR
                | 
                |     Returns a character string from its index in the list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the first character string in the collection is 1, and
                |             the index of the last character string is Count. 
                | 
                |     Returns:
                |         the retrieved string. 
                |     Example:
                | 
                |           The following example returns the third character string in the
                |           list.
                |
                |          Dim MyStr As String
                |          Dim MyList As PspListOfBSTRs
                |          MyStr = PspListOfBSTRs.Item(3)

        :param int i_index:
        :rtype: str
        """
        return self.psp_list_of_bst_rs.Item(i_index)

    def remove_by_index(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveByIndex(long iIndex)
                | 
                |     Remove a character string from the list by specifying its position in the
                |     list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The position of the character string to be removed in the list.
                |
                |     Example:
                | 
                |           The following example removes the second entry in the list. Please
                |           note that the
                |          list index starts with 1.
                |
                |          Dim MyList As PspListOfBSTRs
                |          MyList.Remove(2)

        :param int i_index:
        :rtype: None
        """
        return self.psp_list_of_bst_rs.RemoveByIndex(i_index)

    def __repr__(self):
        return f'PSPListOfBstRs(name="{self.name}")'
